==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/mplayer2/mplayer2outputformat.h <==
#ifndef MPLAYER2OUTPUTFORMAT_H
#define MPLAYER2OUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class MPlayer2OutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:

			~MPlayer2OutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					ret += m_lineBuilder
						.arg( (long)((line->showTime().toMillis()/100.0) + 0.5) )
						.arg( (long)((line->hideTime().toMillis()/100.0) + 0.5) )
						.arg( (primary ? line->primaryText() : line->secondaryText()).replace( "\n", "|" ) );
				}

				return ret;
			}

		protected:

			MPlayer2OutputFormat():
				OutputFormat( "MPlayer2", "mpl" ),
				m_lineBuilder( "[%1][%2]%3\n" )
			{
			}

			const QString m_lineBuilder;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/mplayer2/mplayer2outputformat.h <==
#ifndef MPLAYER2OUTPUTFORMAT_H
#define MPLAYER2OUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class MPlayer2OutputFormat : public OutputFormat
	{
		friend class FormatManager;

		public:

			~MPlayer2OutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					const SString& text = primary ? line->primaryText() : line->secondaryText();

					ret += m_lineBuilder
						.arg( (long)((line->showTime().toMillis()/100.0) + 0.5) )
						.arg( (long)((line->hideTime().toMillis()/100.0) + 0.5) )
						.arg( text.string().replace( "\n", "|" ) );
				}

				return ret;
			}

		protected:

			MPlayer2OutputFormat():
				OutputFormat( "MPlayer2", "mpl" ),
				m_lineBuilder( "[%1][%2]%3\n" )
			{
			}

			const QString m_lineBuilder;
	};
}

#endif
